function [emshape, exshape] = fluofitfix(emshape, exshape, constraints)
%FLUOFITFIX Fix band shapes
%   [EMSHAPE, EXSHAPE] = FLUOFITFIX(EMSHAPE, EXSHAPE, CONSTRAINTS) fixes
%   the EMSHAPE and EXSHAPE band shapes by applying CONSTRAINTS.
%
%   AUTHOR:
%      Wouter Caarls, MPIbpc <wouter@caarls.org>

    for i = 1:3:length(constraints)
        p = constraints{i};
        c = constraints{i+1};
        v = constraints{i+2};
        t = p(1);
        b = p(2)-'0';
        
        switch t
            case 'r'
                emshape((b-1)*3+1) = clamp(emshape((b-1)*3+1), c, v);
            case 'h'
                emshape((b-1)*3+2) = clamp(emshape((b-1)*3+2), c, v);
            case 'n'
                emshape((b-1)*3+3) = clamp(emshape((b-1)*3+3), c, v);
            case 'R'
                exshape((b-1)*3+1) = clamp(exshape((b-1)*3+1), c, v);
            case 'H'
                exshape((b-1)*3+2) = clamp(exshape((b-1)*3+2), c, v);
            case 'N'
                exshape((b-1)*3+3) = clamp(exshape((b-1)*3+3), c, v);
        end

    end
    
    function y = clamp(x, c, v)

        x = (x-c)./v;

        x = x./2-0.5;

        f = floor(x);
        y = 4 .* (x-f-0.5) .* (rem(abs(f), 2)-0.5);

        y = y.*v+c;

    end
end
