function s = val2str(c)        
%VAL2STR Convert arbitrary value to string
%   S = VAL2STR(C) converts C into a string. C can be
%   a numerical or string value, but also a struct or object.
%
%   AUTHOR:
%      Wouter Caarls, MPIbpc <wouter@caarls.org>

    s = [];
    if iscell(c)
        lc = length(c);
        if lc > 0
            for i = 1:(lc-1)
                s = [s val2str(c{i}) ','];
            end
            s = ['{' s val2str(c{lc}) '}'];
        else
            s = '{}';
        end
    elseif ischar(c)
        s = ['''' c ''''];
    elseif numel(c) > 1
        lc = length(c);
        for i = 1:(lc-1)
            s = [s val2str(c(i)) ','];
        end
        s = ['[' s val2str(c(lc)) ']'];
    elseif isstruct(c)
        fn = fieldnames(c);
        lc = length(fn);
        if lc > 0
            for i = 1:(lc-1)
                s = [s fn{i} ':' val2str(c.(fn{i})) ','];
            end
            s = ['<' s fn{lc} ':' val2str(c.(fn{lc})) '>'];
        else
            s = '<>';
        end
    elseif isobject(c)
        s = ['@' class(c)];
    elseif numel(c) == 0
        s = '[]';
    else
        s = num2str(c);
    end
end
